@@ -23,7 +23,7 @@ our @EXPORT_OK = qw( kto_check kto_check_str kto_check_blz
 
 our @EXPORT = qw( kto_check lut_init kto_check_blz kto_check_at %kto_retval );
 
-our $VERSION = '2.97';
+our $VERSION = '2.98';
 
 require XSLoader;
 XSLoader::load('Business::KontoCheck', $VERSION);
@@ -275,10 +275,11 @@ sub lut_nachfolge_blz
 
 
 %Business::KontoCheck::kto_retval = (
+ -76 => 'User-Blocks mssen einen Typ > 1000 haben',
  -75 => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
  -74 => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
  -73 => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
- -72 => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen (keine Blanks, Umlaute...)',
+ -72 => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen',
  -71 => 'Die Lnge des IPI-Verwendungszwecks darf maximal 18 Byte sein',
  -70 => 'Es wurde eine LUT-Datei im Format 1.0/1.1 geladen',
  -69 => 'Bei der Kontoprfung fehlt ein notwendiger Parameter (BLZ oder Konto)',
@@ -359,10 +360,11 @@ sub lut_nachfolge_blz
    6 => 'Die Datei ist im alten LUT-Format (1.0/1.1)',
    7 => 'ok; es wurde allerdings eine LUT-Datei im alten Format (1.0/1.1) generiert',
 
+'LUT2_NO_USER_BLOCK'                     => 'User-Blocks mssen einen Typ > 1000 haben',
 'INVALID_SET'                            => 'fr ein LUT-Set sind nur die Werte 0, 1 oder 2 mglich',
 'NO_GERMAN_BIC'                          => 'Ein Konto kann kann nur fr deutsche Banken geprft werden',
 'IPI_CHECK_INVALID_LENGTH'               => 'Der zu validierende strukturierete Verwendungszweck mu genau 20 Zeichen enthalten',
-'IPI_INVALID_CHARACTER'                  => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen (keine Blanks, Umlaute...)',
+'IPI_INVALID_CHARACTER'                  => 'Im strukturierten Verwendungszweck drfen nur alphanumerische Zeichen vorkommen',
 'IPI_INVALID_LENGTH'                     => 'Die Lnge des IPI-Verwendungszwecks darf maximal 18 Byte sein',
 'LUT1_FILE_USED'                         => 'Es wurde eine LUT-Datei im Format 1.0/1.1 geladen',
 'MISSING_PARAMETER'                      => 'Bei der Kontoprfung fehlt ein notwendiger Parameter (BLZ oder Konto)',
@@ -445,6 +447,7 @@ sub lut_nachfolge_blz
 );
 
 %Business::KontoCheck::kto_retval_kurz = (
+ -76 => 'LUT2_NO_USER_BLOCK',
  -75 => 'INVALID_SET',
  -74 => 'NO_GERMAN_BIC',
  -73 => 'IPI_CHECK_INVALID_LENGTH',
